==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/StackedAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedAreaSeriesDescription } from "./StackedAreaSeriesDescription";
/**
 * @hidden
 */
export let StackedAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedAreaSeriesDescriptionMetadata.a == null) {
                StackedAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedAreaSeriesDescriptionMetadata.c(StackedAreaSeriesDescriptionMetadata.a);
            }
            if (a.j(StackedAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(StackedAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            StackedAreaSeriesDescriptionMetadata.b(a);
            a.aa("StackedAreaSeries", () => new StackedAreaSeriesDescription());
            a.z("StackedAreaSeries", StackedAreaSeriesDescriptionMetadata.a);
        }
    }
    StackedAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedAreaSeriesDescriptionMetadata, 'StackedAreaSeriesDescriptionMetadata');
    StackedAreaSeriesDescriptionMetadata.a = null;
    return StackedAreaSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/StackedAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedAreaSeriesDescription } from "./StackedAreaSeriesDescription";
/**
 * @hidden
 */
export let StackedAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (StackedAreaSeriesDescriptionMetadata.a == null) {
                StackedAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedAreaSeriesDescriptionMetadata.c(StackedAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(StackedAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(StackedAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            StackedAreaSeriesDescriptionMetadata.b(a);
            a.ac("StackedAreaSeries", () => new StackedAreaSeriesDescription());
            a.ab("StackedAreaSeries", StackedAreaSeriesDescriptionMetadata.a);
        }
    }
    StackedAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedAreaSeriesDescriptionMetadata, 'StackedAreaSeriesDescriptionMetadata');
    StackedAreaSeriesDescriptionMetadata.a = null;
    return StackedAreaSeriesDescriptionMetadata;
})();
